import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataNewrelicNotificationDestinationConfig extends cdktf.TerraformMetaArguments {
    /**
    * The account ID under which to put the destination.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/d/notification_destination#account_id DataNewrelicNotificationDestination#account_id}
    */
    readonly accountId?: number;
    /**
    * Indicates whether the destination is active.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/d/notification_destination#active DataNewrelicNotificationDestination#active}
    */
    readonly active?: boolean | cdktf.IResolvable;
    /**
    * The ID of the destination.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/d/notification_destination#id DataNewrelicNotificationDestination#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * The name of the destination.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/d/notification_destination#name DataNewrelicNotificationDestination#name}
    */
    readonly name?: string;
    /**
    * The type of the destination. One of: (WEBHOOK, EMAIL, SERVICE_NOW, PAGERDUTY_ACCOUNT_INTEGRATION, PAGERDUTY_SERVICE_INTEGRATION, JIRA, SLACK, SLACK_COLLABORATION, SLACK_LEGACY, MOBILE_PUSH, EVENT_BRIDGE).
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/d/notification_destination#type DataNewrelicNotificationDestination#type}
    */
    readonly type?: string;
    /**
    * auth_basic block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/d/notification_destination#auth_basic DataNewrelicNotificationDestination#auth_basic}
    */
    readonly authBasic?: DataNewrelicNotificationDestinationAuthBasic;
    /**
    * auth_token block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/d/notification_destination#auth_token DataNewrelicNotificationDestination#auth_token}
    */
    readonly authToken?: DataNewrelicNotificationDestinationAuthToken;
    /**
    * property block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/d/notification_destination#property DataNewrelicNotificationDestination#property}
    */
    readonly property?: DataNewrelicNotificationDestinationProperty[] | cdktf.IResolvable;
}
export interface DataNewrelicNotificationDestinationAuthBasic {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/d/notification_destination#user DataNewrelicNotificationDestination#user}
    */
    readonly user?: string;
}
export declare function dataNewrelicNotificationDestinationAuthBasicToTerraform(struct?: DataNewrelicNotificationDestinationAuthBasicOutputReference | DataNewrelicNotificationDestinationAuthBasic): any;
export declare class DataNewrelicNotificationDestinationAuthBasicOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataNewrelicNotificationDestinationAuthBasic | undefined;
    set internalValue(value: DataNewrelicNotificationDestinationAuthBasic | undefined);
    private _user?;
    get user(): string;
    set user(value: string);
    resetUser(): void;
    get userInput(): string | undefined;
}
export interface DataNewrelicNotificationDestinationAuthToken {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/d/notification_destination#prefix DataNewrelicNotificationDestination#prefix}
    */
    readonly prefix?: string;
}
export declare function dataNewrelicNotificationDestinationAuthTokenToTerraform(struct?: DataNewrelicNotificationDestinationAuthTokenOutputReference | DataNewrelicNotificationDestinationAuthToken): any;
export declare class DataNewrelicNotificationDestinationAuthTokenOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataNewrelicNotificationDestinationAuthToken | undefined;
    set internalValue(value: DataNewrelicNotificationDestinationAuthToken | undefined);
    private _prefix?;
    get prefix(): string;
    set prefix(value: string);
    resetPrefix(): void;
    get prefixInput(): string | undefined;
}
export interface DataNewrelicNotificationDestinationProperty {
    /**
    * Notification property display key.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/d/notification_destination#display_value DataNewrelicNotificationDestination#display_value}
    */
    readonly displayValue?: string;
    /**
    * Notification property key.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/d/notification_destination#key DataNewrelicNotificationDestination#key}
    */
    readonly key: string;
    /**
    * Notification property label.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/d/notification_destination#label DataNewrelicNotificationDestination#label}
    */
    readonly label?: string;
    /**
    * Notification property value.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/d/notification_destination#value DataNewrelicNotificationDestination#value}
    */
    readonly value: string;
}
export declare function dataNewrelicNotificationDestinationPropertyToTerraform(struct?: DataNewrelicNotificationDestinationProperty | cdktf.IResolvable): any;
export declare class DataNewrelicNotificationDestinationPropertyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataNewrelicNotificationDestinationProperty | cdktf.IResolvable | undefined;
    set internalValue(value: DataNewrelicNotificationDestinationProperty | cdktf.IResolvable | undefined);
    private _displayValue?;
    get displayValue(): string;
    set displayValue(value: string);
    resetDisplayValue(): void;
    get displayValueInput(): string | undefined;
    private _key?;
    get key(): string;
    set key(value: string);
    get keyInput(): string | undefined;
    private _label?;
    get label(): string;
    set label(value: string);
    resetLabel(): void;
    get labelInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    get valueInput(): string | undefined;
}
export declare class DataNewrelicNotificationDestinationPropertyList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DataNewrelicNotificationDestinationProperty[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataNewrelicNotificationDestinationPropertyOutputReference;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/newrelic/d/notification_destination newrelic_notification_destination}
*/
export declare class DataNewrelicNotificationDestination extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "newrelic_notification_destination";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/newrelic/d/notification_destination newrelic_notification_destination} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataNewrelicNotificationDestinationConfig
    */
    constructor(scope: Construct, id: string, config: DataNewrelicNotificationDestinationConfig);
    private _accountId?;
    get accountId(): number;
    set accountId(value: number);
    resetAccountId(): void;
    get accountIdInput(): number | undefined;
    private _active?;
    get active(): boolean | cdktf.IResolvable;
    set active(value: boolean | cdktf.IResolvable);
    resetActive(): void;
    get activeInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    get lastSent(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    get status(): string;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
    private _authBasic;
    get authBasic(): DataNewrelicNotificationDestinationAuthBasicOutputReference;
    putAuthBasic(value: DataNewrelicNotificationDestinationAuthBasic): void;
    resetAuthBasic(): void;
    get authBasicInput(): DataNewrelicNotificationDestinationAuthBasic | undefined;
    private _authToken;
    get authToken(): DataNewrelicNotificationDestinationAuthTokenOutputReference;
    putAuthToken(value: DataNewrelicNotificationDestinationAuthToken): void;
    resetAuthToken(): void;
    get authTokenInput(): DataNewrelicNotificationDestinationAuthToken | undefined;
    private _property;
    get property(): DataNewrelicNotificationDestinationPropertyList;
    putProperty(value: DataNewrelicNotificationDestinationProperty[] | cdktf.IResolvable): void;
    resetProperty(): void;
    get propertyInput(): cdktf.IResolvable | DataNewrelicNotificationDestinationProperty[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
